PyXMake Developer Guide: PyXMake.VTL.ssh_ifort Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions | Variables
PyXMake.VTL.ssh_ifort Namespace Reference

## Functions
| main (BuildID, user, key, files=VTL.GetSourceCode(0), command=VTL.GetBuildCommand(5), source=os.path.join(__mcd_core_path,"src"), include=[posixpath.join(__mcd_cluster_incpath, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, "x64")], make=__mcd_cluster_dev, link=[posixpath.join(__mcd_cluster_libpath, ".".join(["lib"+x,"a"])) for x in VTL.GetLinkDependency(0, 4, "x64")], environment=VTL.GetEnvironment(0), architecture="x64", scratch=VTL.Scratch, verbosity=0, incremental=False, host="129.247.54.37", port=22, **kwargs)

## Variables
| parser = argparse.ArgumentParser(description="Build a static Fortran library remotely on the institute cluster")
| metavar
| nargs
| help
| _ = sys.argv[1]
| args
| user = args.user[0]
| key = args.key[0]
| box_source = os.path.join(__mcd_core_path,"external","boxbeam")
list | box_make = [posixpath.join(__mcd_cluster_dev,"include","boxbeam"), posixpath.join(__mcd_cluster_dev,"lib")]
| files
| source = os.path.join(__mcd_core_path,"external",BuildID)
| include
| make = [posixpath.join(__mcd_cluster_dev,"include","toms"),posixpath.join(__mcd_cluster_dev,"lib")]
| link
| disp_source = os.path.join(__mcd_core_path,"external","dispmodule","Fortran90","Src")
list | disp_make = [posixpath.join(__mcd_cluster_dev,"include","dispmodule"), posixpath.join(__mcd_cluster_dev,"lib")]
| command
| incremental
list | BuildIDs = [os.path.splitext(x)[0].lower() for x in VTL.GetSourceCode(6)]
list | srcfile = [x for x in VTL.GetSourceCode(6) if x.startswith(BuildID)]
str | style = False
| toms_source = os.path.join(__mcd_core_path,"external","toms")
| BuildID
| combine
| libs
| pchip_replace = collections.OrderedDict([('rand',"pchip_rand"), ('RAND',"pchip_rand"), ('subroutine timestamp ( )','subroutine timestamp ( ) BIND(C, NAME="pchip_timestamp")')])
| precommand
| replace

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Compile Fortran source on the institute cluster.
                 Uses main function

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake
          - SSH key

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.ssh_ifort.main | ( |  | BuildID,
|  |  | user,
|  |  | key,
|  |  | files = VTL.GetSourceCode(0),
|  |  | command = VTL.GetBuildCommand(5),
|  |  | source = os.path.join(__mcd_core_path,"src"),
|  |  | include = [posixpath.join(__mcd_cluster_incpath, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, "x64")],
|  |  | make = __mcd_cluster_dev,
|  |  | link = [posixpath.join(__mcd_cluster_libpath, ".".join(["lib"+x,"a"])) for x in VTL.GetLinkDependency(0, 4, "x64")],
|  |  | environment = VTL.GetEnvironment(0),
|  |  | architecture = "x64",
|  |  | scratch = VTL.Scratch,
|  |  | verbosity = 0,
|  |  | incremental = False,
|  |  | host = "129.247.54.37",
|  |  | port = 22,
|  | ** | kwargs )

    Main function to execute the script.

Definition at line 55 of file ssh_ifort.py.

## Variable Documentation

## ◆ _

PyXMake.VTL.ssh_ifort._ = sys.argv[1]
| protected

Definition at line 119 of file ssh_ifort.py.

## ◆ args

PyXMake.VTL.ssh_ifort.args

Definition at line 120 of file ssh_ifort.py.

## ◆ box_make

PyXMake.VTL.ssh_ifort.box_make = [posixpath.join(__mcd_cluster_dev,"include","boxbeam"), posixpath.join(__mcd_cluster_dev,"lib")]

Definition at line 135 of file ssh_ifort.py.

## ◆ box_source

PyXMake.VTL.ssh_ifort.box_source = os.path.join(__mcd_core_path,"external","boxbeam")

Definition at line 134 of file ssh_ifort.py.

## ◆ BuildID

PyXMake.VTL.ssh_ifort.BuildID

Definition at line 157 of file ssh_ifort.py.

## ◆ BuildIDs

list PyXMake.VTL.ssh_ifort.BuildIDs = [os.path.splitext(x)[0].lower() for x in VTL.GetSourceCode(6)]

Definition at line 146 of file ssh_ifort.py.

## ◆ combine

PyXMake.VTL.ssh_ifort.combine

Definition at line 158 of file ssh_ifort.py.

## ◆ command

PyXMake.VTL.ssh_ifort.command

Definition at line 141 of file ssh_ifort.py.

## ◆ disp_make

PyXMake.VTL.ssh_ifort.disp_make = [posixpath.join(__mcd_cluster_dev,"include","dispmodule"), posixpath.join(__mcd_cluster_dev,"lib")]

Definition at line 140 of file ssh_ifort.py.

## ◆ disp_source

PyXMake.VTL.ssh_ifort.disp_source = os.path.join(__mcd_core_path,"external","dispmodule","Fortran90","Src")

Definition at line 139 of file ssh_ifort.py.

## ◆ files

PyXMake.VTL.ssh_ifort.files

Definition at line 136 of file ssh_ifort.py.

## ◆ help

PyXMake.VTL.ssh_ifort.help

Definition at line 115 of file ssh_ifort.py.

## ◆ include

PyXMake.VTL.ssh_ifort.include

Definition at line 136 of file ssh_ifort.py.

## ◆ incremental

PyXMake.VTL.ssh_ifort.incremental

Definition at line 142 of file ssh_ifort.py.

## ◆ key

PyXMake.VTL.ssh_ifort.key = args.key[0]

Definition at line 127 of file ssh_ifort.py.

## ◆ libs

PyXMake.VTL.ssh_ifort.libs

Definition at line 158 of file ssh_ifort.py.

## ◆ link

PyXMake.VTL.ssh_ifort.link

Definition at line 136 of file ssh_ifort.py.

## ◆ make

list PyXMake.VTL.ssh_ifort.make = [posixpath.join(__mcd_cluster_dev,"include","toms"),posixpath.join(__mcd_cluster_dev,"lib")]

Definition at line 136 of file ssh_ifort.py.

## ◆ metavar

PyXMake.VTL.ssh_ifort.metavar

Definition at line 115 of file ssh_ifort.py.

## ◆ nargs

PyXMake.VTL.ssh_ifort.nargs

Definition at line 115 of file ssh_ifort.py.

## ◆ parser

PyXMake.VTL.ssh_ifort.parser = argparse.ArgumentParser(description="Build a static Fortran library remotely on the institute cluster")

Definition at line 114 of file ssh_ifort.py.

## ◆ pchip_replace

PyXMake.VTL.ssh_ifort.pchip_replace = collections.OrderedDict([('rand',"pchip_rand"), ('RAND',"pchip_rand"), ('subroutine timestamp ( )','subroutine timestamp ( ) BIND(C, NAME="pchip_timestamp")')])

Definition at line 161 of file ssh_ifort.py.

## ◆ precommand

PyXMake.VTL.ssh_ifort.precommand

Definition at line 173 of file ssh_ifort.py.

## ◆ replace

PyXMake.VTL.ssh_ifort.replace

Definition at line 173 of file ssh_ifort.py.

## ◆ source

PyXMake.VTL.ssh_ifort.source = os.path.join(__mcd_core_path,"external",BuildID)

Definition at line 136 of file ssh_ifort.py.

## ◆ srcfile

list PyXMake.VTL.ssh_ifort.srcfile = [x for x in VTL.GetSourceCode(6) if x.startswith(BuildID)]

Definition at line 148 of file ssh_ifort.py.

## ◆ style

str PyXMake.VTL.ssh_ifort.style = False

Definition at line 150 of file ssh_ifort.py.

## ◆ toms_source

PyXMake.VTL.ssh_ifort.toms_source = os.path.join(__mcd_core_path,"external","toms")

Definition at line 154 of file ssh_ifort.py.

## ◆ user

PyXMake.VTL.ssh_ifort.user = args.user[0]

Definition at line 126 of file ssh_ifort.py.